@@ -75,6 +75,28 @@ sub new
     my $interface = shift;
     my $params    = shift;
 
+    my $self = {};
+    
+    # Initialize the error string and the error level.
+    $self->{'errorString'} = "";
+    $self->{'error'} = 0;
+    
+    # Bless the object.
+    bless($self, $className);
+    
+    # The backend interface object.
+    $self->{'interface'} = $interface;
+    
+    if(!$interface)
+    {
+	$self->{'errorString'} .= "\nError (UMLS::Similarity::vector->new()) - ";
+	$self->{'errorString'} .= "An interface object is required.";
+	$self->{'error'} = 2;
+    }
+    
+    # The backend interface object.
+    $self->{'interface'} = $interface;
+
     $params = {} if(!defined $params);
 
     $vectorindex  = $params->{'vectorindex'};
@@ -91,19 +113,31 @@ sub new
 
     if (defined $dictfile) {
 	
-	open(DICT, "<$dictfile")
-	    or die("Error: cannot open file '$dictfile' for output index.\n");
+	open(DICT, "$dictfile")
+	    or die("Error: cannot open dictionary file ($dictfile).\n");
 	
 	while(<DICT>) {
 	    chomp;
-
+	    
 	    if($_=~/^\s*$/) { next; }
-
+	    
 	    my @defs = split/ /;
 	    my $concept = shift @defs; 
 	    my $definition = join (" ", @defs);	
-
-	    $dictionary{$concept} = $definition;	
+	    if($concept=~/C[0-9]+/) {
+		$dictionary{$concept} = $definition;	
+	    }
+	    else {
+		my @cuis = $interface->getConceptList($concept);
+		foreach my $cui (@cuis) {
+		    if(exists $dictionary{$cui}) {
+			$dictionary{$cui} .= " " . $definition;
+		    }
+		    else {
+			$dictionary{$cui} = $definition;
+		    }
+		}
+	    }
 	}
 	close DICT;
     }
@@ -137,27 +171,6 @@ sub new
     }
     
     
-    my $self = {};
-    
-    # Initialize the error string and the error level.
-    $self->{'errorString'} = "";
-    $self->{'error'} = 0;
-    
-    # Bless the object.
-    bless($self, $className);
-    
-    # The backend interface object.
-    $self->{'interface'} = $interface;
-    
-    if(!$interface)
-    {
-	$self->{'errorString'} .= "\nError (UMLS::Similarity::vector->new()) - ";
-	$self->{'errorString'} .= "An interface object is required.";
-	$self->{'error'} = 2;
-    }
-    
-    # The backend interface object.
-    $self->{'interface'} = $interface;
 
     return $self;
 }
@@ -454,8 +467,7 @@ __END__
 
 UMLS::Similarity::vector - Perl module for computing semantic relatedness
 of concepts in the Unified Medical Language System (UMLS) using the 
-method described by Resnik 1995.
-
+method described by Patwardhan (2003).
 =head1 SYNOPSIS
 
   use UMLS::Interface;
@@ -492,11 +504,67 @@ method described by Resnik 1995.
 
 =head1 DESCRIPTION
 
-This module computes the semantic relatedness of two concepts in 
-the UMLS according to a method described by Resnik (1995). The 
-relatedness measure proposed by Resnik is the information content 
-of the least common subsumer of the two concepts. 
+This module computes the semantic relatedness of two concepts in the  
+UMLS according to a method described by Patwardhan & Pedersen (2006). 
+"Using WordNet Based Context Vectors to Estimate the Semantic Relatedness 
+of Concepts"  (Patwardhan and Pedersen) - Appears in the Proceedings of 
+the EACL 2006 Workshop Making Sense of Sense - Bringing Computational 
+Linguistics and Psycholinguistics Together, pp. 1-8, April 4, 2006, Trento, Italy.
+http://www.d.umn.edu/~tpederse/Pubs/eacl2006-vector.pdf
 
+The co-occurrence matrix and index file used in the vector method are 
+prepared by vector-input.pl method. Index file assigns each term of the
+bigrams a number and also records the vector position and length which 
+starts the term of the co-occrrence matrix. For example, for the following 
+bigrams list which are generated by the text "This is the first line Of a LONG file."
+
+9
+LONG<>file<>1 1 1
+Of<>a<>1 1 1
+This<>is<>1 1 1
+a<>LONG<>1 1 1
+file<>.<>1 1 1
+first<>line<>1 1 1
+is<>the<>1 1 1
+line<>Of<>1 1 1
+the<>first<>1 1 1
+
+The index file for the terms show up in the above will be:
+
+. 1 0
+LONG 2 0 8
+Of 3 8 8
+This 4 16 8
+a 5 24 8
+file 6 32 8
+first 7 40 8
+is 8 48 9
+line 9 57 8
+the 10 65 9
+
+The co-occurrence matrix file will be: 
+
+2: 6 1
+3: 5 1
+4: 8 1
+5: 2 1
+6: 1 1
+7: 9 1
+8: 10 1
+9: 3 1
+10: 7 1
+
+Each index file assigns the term a number and also record the 
+vector start position and length of the vector of the co-occurrence
+matrix. For example, the first line of the matrix file "2: 6 1" means
+for the term '2' which is 'LONG', it has a bigram pair with term 
+'6' which is 'file', and the frequency is 1. In the index file, for 
+the term 'LONG', it use '2' to represent 'LONG' and it starts at the 
+'0' position of the file(byte) and the vector has lenghth '8'. The 
+vector-input.pl requires the bigrams are sorted, and you could use 
+count2huge.pl method of Text-NSP to convert the output of count.pl 
+to huge-count.pl. 
+    
 =head1 USAGE
 
 The semantic relatedness modules in this distribution are built as classes
